@@ -16,6 +16,7 @@ class SomeErrors(ErrorEnum):
     NOT_SO_IMPORTANT_ERROR = (auto(), 500)
     """This error is not very important, but it has some additional details."""
 
+    @classmethod
     def error_response_models(cls) -> dict:
         return {
             cls.NOT_SO_IMPORTANT_ERROR: NotSoImportantErrorDetails,
@@ -79,3 +80,6 @@ print(SomeErrors.build_responses(SomeErrors.SOME_VERY_IMPORTANT_ERROR))  # noqa:
 #       }
 #    }
 # }
+
+print(SomeErrors.from_str("some_very_important_error"))
+# SomeErrors.SOME_VERY_IMPORTANT_ERROR
